@@ -26,8 +26,10 @@ def remove_folded_layers(
             x = intermediate_outputs[network_dict["input_layers_of"][layer.name][0]]
             intermediate_outputs[layer.name] = x
         else:
-            if len(network_dict["input_layers_of"][layer.name]) == 1 or isinstance(
-                layer, tf.keras.layers.Lambda
+            if (
+                len(network_dict["input_layers_of"][layer.name]) == 1
+                or isinstance(layer, tf.keras.layers.Lambda)
+                or "tfoplambda" in type(layer).__name__.lower()
             ):
                 x = call_lambda_layer(
                     layer_input=layer_input, model=model, layer=layer, layer_cpt=cpt + 1
@@ -37,7 +39,7 @@ def remove_folded_layers(
                 if (
                     isinstance(layer, tf.keras.layers.Add)
                     or isinstance(layer, tf.keras.layers.Multiply)
-                    or isinstance(layer, tf.keras.layers.Concatenate)
+                    or isinstance(layer, (tf.keras.layers.Concatenate))
                 ):
                     x = layer(
                         [
@@ -58,7 +60,9 @@ def remove_folded_layers(
         network_dict["new_output_tensor_of"].update({layer.name: x})
         if layer.name in model.output_names:
             model_outputs.append(x)
-    output_model = tf.keras.Model(inputs=model.inputs, outputs=model_outputs[-1])
+    if len(model_outputs)==0:
+        model_outputs=model_outputs[0]
+    output_model = tf.keras.Model(inputs=model.inputs, outputs=model_outputs)
     for layer in output_model.layers:
         for node in layer._outbound_nodes:
             layer_name = node.outbound_layer.name
