@@ -15,6 +15,20 @@ from typing import Dict, Tuple
 import tensorflow as tf
 
 
+def should_be_folded(model: tf.keras.Model) -> bool:
+    """
+    if a model does not contain any bn layers let's not touch it
+
+    Args:
+        model: model to study
+    """
+    should_be_folded = False
+    for layer in model.layers:
+        if isinstance(layer, tf.keras.layers.BatchNormalization):
+            should_be_folded = True
+    return should_be_folded
+
+
 def fold_tensorflow_model(
     model: tf.keras.Model, verbose: bool
 ) -> Tuple[tf.keras.Model, str]:
@@ -22,6 +36,18 @@ def fold_tensorflow_model(
     In this functio nwe fold the model
     But we also update the batchnorm statistics adequately
     """
+    if not should_be_folded(model=model):
+        if verbose:
+            print("\r+" + "-" * 36 + "+")
+            print(f"| {model.name.center(34).replace('_', ' ')} |")
+            print("\r+" + "-" * 36 + "+")
+            print(f"| BN layers folded         | " f'{f"{0}".center(7):<7} |')
+            print(
+                f"| BN layers not folded     | "
+                f'{f"{len(model.layers)}".center(7):<7} |'
+            )
+            print("+" + "-" * 36 + "+")
+        return model, ""
     model_to_fold = deep_copy_a_model(model=model)
     backward_graph = get_graph_as_dict(model=model_to_fold)
     forward_graph = reverse_graph(graph=backward_graph)
@@ -56,6 +82,8 @@ def fold_tensorflow_model(
         )
     fold_weights(model=model_to_fold, fold_dict=fold_dict)
     model_to_fold = remove_folded_layers(
-        model=model_to_fold, backward_graph=backward_graph, fold_dict=fold_dict
+        model=model_to_fold,
+        backward_graph=get_graph_as_dict(model=model_to_fold),
+        fold_dict=fold_dict,
     )
     return model_to_fold, f"{len(fold_dict)}/{unfolded_layers}"
