@@ -11,11 +11,13 @@ def fold_leaf_forward(
     mu: np.ndarray,
     sigma: np.ndarray,
     layer: tf.keras.layers.Layer,
+    epsilon: float = 1.0e-3,
 ):
     """ """
     if isinstance(layer, tf.keras.layers.Conv2D):
         layer.set_weights(
             fold_leaf_forward_conv(
+                epsilon=epsilon,
                 W=layer.weights[0].numpy(),
                 b=layer.weights[1].numpy(),
                 gamma=gamma,
@@ -27,6 +29,7 @@ def fold_leaf_forward(
     elif isinstance(layer, tf.keras.layers.DepthwiseConv2D):
         layer.set_weights(
             fold_leaf_forward_depthwiseconv(
+                epsilon=epsilon,
                 W=layer.weights[0].numpy(),
                 b=layer.weights[1].numpy(),
                 gamma=gamma,
@@ -38,6 +41,7 @@ def fold_leaf_forward(
     elif isinstance(layer, tf.keras.layers.Dense):
         layer.set_weights(
             fold_leaf_forward_dense(
+                epsilon=epsilon,
                 W=layer.weights[0].numpy(),
                 b=layer.weights[1].numpy(),
                 gamma=gamma,
@@ -57,11 +61,13 @@ def fold_leaf_backward(
     mu: np.ndarray,
     sigma: np.ndarray,
     layer: tf.keras.layers.Layer,
+    epsilon: float = 1.0e-3,
 ):
     """ """
     if isinstance(layer, tf.keras.layers.Conv2D):
         layer.set_weights(
             fold_leaf_backward_conv(
+                epsilon=epsilon,
                 W=layer.weights[0].numpy(),
                 b=layer.weights[1].numpy(),
                 gamma=gamma,
@@ -73,6 +79,7 @@ def fold_leaf_backward(
     elif isinstance(layer, tf.keras.layers.DepthwiseConv2D):
         layer.set_weights(
             fold_leaf_backward_depthwiseconv(
+                epsilon=epsilon,
                 W=layer.weights[0].numpy(),
                 b=layer.weights[1].numpy(),
                 gamma=gamma,
@@ -84,6 +91,7 @@ def fold_leaf_backward(
     elif isinstance(layer, tf.keras.layers.Dense):
         layer.set_weights(
             fold_leaf_backward_dense(
+                epsilon=epsilon,
                 W=layer.weights[0].numpy(),
                 b=layer.weights[1].numpy(),
                 gamma=gamma,
@@ -95,6 +103,7 @@ def fold_leaf_backward(
     else:
         layer.set_weights(
             fold_leaf_backward_bn(
+                epsilon=epsilon,
                 gamma_=layer.weights[0].numpy(),
                 beta_=layer.weights[1].numpy(),
                 mu_=layer.weights[2].numpy(),
@@ -114,12 +123,17 @@ def fold_leaf(
     sigma: np.ndarray,
     layer: tf.keras.layers.Layer,
     forward: bool,
+    epsilon: float = 1.0e-3,
 ):
     """ """
     if forward:
-        fold_leaf_forward(gamma=gamma, beta=beta, mu=mu, sigma=sigma, layer=layer)
+        fold_leaf_forward(
+            epsilon=epsilon, gamma=gamma, beta=beta, mu=mu, sigma=sigma, layer=layer
+        )
     else:
-        fold_leaf_backward(gamma=gamma, beta=beta, mu=mu, sigma=sigma, layer=layer)
+        fold_leaf_backward(
+            epsilon=epsilon, gamma=gamma, beta=beta, mu=mu, sigma=sigma, layer=layer
+        )
 
 
 def fold_root_forward(
@@ -128,11 +142,13 @@ def fold_root_forward(
     mu: np.ndarray,
     sigma: np.ndarray,
     layer: tf.keras.layers.Layer,
+    epsilon: float = 1.0e-3,
 ):
     """ """
     if isinstance(layer, tf.keras.layers.Conv2D):
         layer.set_weights(
             fold_root_forward_conv(
+                epsilon=epsilon,
                 W=layer.weights[0].numpy(),
                 b=layer.weights[1].numpy(),
                 gamma=gamma,
@@ -144,6 +160,7 @@ def fold_root_forward(
     elif isinstance(layer, tf.keras.layers.DepthwiseConv2D):
         layer.set_weights(
             fold_root_forward_depthwiseconv(
+                epsilon=epsilon,
                 W=layer.weights[0].numpy(),
                 b=layer.weights[1].numpy(),
                 gamma=gamma,
@@ -155,6 +172,7 @@ def fold_root_forward(
     elif isinstance(layer, tf.keras.layers.Dense):
         layer.set_weights(
             fold_root_forward_dense(
+                epsilon=epsilon,
                 W=layer.weights[0].numpy(),
                 b=layer.weights[1].numpy(),
                 gamma=gamma,
@@ -174,11 +192,13 @@ def fold_root_backward(
     mu: np.ndarray,
     sigma: np.ndarray,
     layer: tf.keras.layers.Layer,
+    epsilon: float = 1.0e-3,
 ):
     """ """
     if isinstance(layer, tf.keras.layers.Conv2D):
         layer.set_weights(
             fold_root_backward_conv(
+                epsilon=epsilon,
                 W=layer.weights[0].numpy(),
                 b=layer.weights[1].numpy(),
                 gamma=gamma,
@@ -190,6 +210,7 @@ def fold_root_backward(
     elif isinstance(layer, tf.keras.layers.DepthwiseConv2D):
         layer.set_weights(
             fold_root_backward_depthwiseconv(
+                epsilon=epsilon,
                 W=layer.weights[0].numpy(),
                 b=layer.weights[1].numpy(),
                 gamma=gamma,
@@ -201,6 +222,7 @@ def fold_root_backward(
     elif isinstance(layer, tf.keras.layers.Dense):
         layer.set_weights(
             fold_root_backward_dense(
+                epsilon=epsilon,
                 W=layer.weights[0].numpy(),
                 b=layer.weights[1].numpy(),
                 gamma=gamma,
@@ -211,6 +233,7 @@ def fold_root_backward(
         )
     else:
         new_W, new_b = fold_root_backward_bn(
+            epsilon=epsilon,
             W=layer.weights[0].numpy(),
             b=layer.weights[1].numpy(),
             gamma=gamma,
@@ -230,12 +253,17 @@ def fold_root(
     sigma: np.ndarray,
     layer: tf.keras.layers.Layer,
     forward: bool,
+    epsilon: float = 1.0e-3,
 ):
     """ """
     if forward:
-        fold_root_forward(gamma=gamma, beta=beta, mu=mu, sigma=sigma, layer=layer)
+        fold_root_forward(
+            epsilon=epsilon, gamma=gamma, beta=beta, mu=mu, sigma=sigma, layer=layer
+        )
     else:
-        fold_root_backward(gamma=gamma, beta=beta, mu=mu, sigma=sigma, layer=layer)
+        fold_root_backward(
+            epsilon=epsilon, gamma=gamma, beta=beta, mu=mu, sigma=sigma, layer=layer
+        )
 
 
 def fold_weights(model: tf.keras.Model, fold_dict: Dict[str, tuple]):
@@ -245,6 +273,7 @@ def fold_weights(model: tf.keras.Model, fold_dict: Dict[str, tuple]):
     for layer_name, (roots, leaves, forward) in fold_dict.items():
         bn_weights = model.get_layer(layer_name).weights
         weight_shape = bn_weights[0].numpy().shape
+        epsilon = model.get_layer(layer_name).epsilon
         gamma = np.ones(weight_shape)
         beta = np.zeros(weight_shape)
         mu = np.zeros(weight_shape)
@@ -261,6 +290,7 @@ def fold_weights(model: tf.keras.Model, fold_dict: Dict[str, tuple]):
 
         for leaf in leaves:
             fold_leaf(
+                epsilon=epsilon,
                 gamma=gamma,
                 beta=beta,
                 mu=mu,
@@ -270,6 +300,7 @@ def fold_weights(model: tf.keras.Model, fold_dict: Dict[str, tuple]):
             )
         for root in roots:
             fold_root(
+                epsilon=epsilon,
                 gamma=gamma,
                 beta=beta,
                 mu=mu,
